9 September 2019

10 links · Monday

Compiler Explorer - CUDA (NVCC 10.1 Update 1)

// Type your code here, or load an example. __global__ void square(int *array, int n) { int tid = blockIdx.x; if (tid < n) array[tid] = array[tid] * array[tid]; }

Python 2.7 Countdown

Python 2.7 will retire in 2020. Learn more and see the countdown here.

MvvmCross/MvvmCross

The .NET MVVM framework for cross-platform solutions, including Xamarin.iOS, Xamarin.Android, Windows and Mac. - MvvmCross/MvvmCross

Common Systems Programming Optimizations & Tricks - paulcavallaro

Today’s blog post is an overview of some common optimization techniques and neat tricks for doing “systems programming” – whatever that means today. We’ll walk through some methods to make your code run faster, be more efficient, and to squeeze just a little m…

Announcing CT Monitoring for Report URI!

I've spoken a lot about Certificate Transparency on my blog recently and how powerful it is for site operators to be able to keep track of certificates issued for their domains. We plan to make that even easier by integrating CT monitoring into Report URI. Ce…

Australia’s 2020 Cyber Security Strategy

The Australian Government is developing our nation’s next Cyber Security Strategy as part of its commitment to protecting Australians from cyber threats.